<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package quna
 */

if ( ! function_exists( 'quna_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function quna_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( ' %s', 'post date', 'quna' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'quna_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function quna_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( '%s', 'post author', 'quna' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'quna_author_avatar' ) ) :
	/**
	 * Author avatar
	 */
	function quna_author_avatar() {

		$u_email = get_the_author_meta( 'user_email' );

		return get_avatar($u_email, 96);

	}

endif;

if ( ! function_exists( 'quna_author_avatar_html' ) ) :

	function quna_author_avatar_html() {
		$avatar = quna_author_avatar();

		if($avatar) {
			echo '<div class="author-avatar"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">'.quna_author_avatar().'</a></div>';
		}

	}

endif;

function quna_avatar_posted_by() {
	echo '<div class="avatar-posted-byline">';
	quna_author_avatar_html(); quna_posted_by();
	echo '</div>';
}


function quna_author_box() {
	?>

	<div class="post-author-box">
		<?php quna_author_avatar_html(); ?>
		<div class="author-details">
			<div>
				<?php quna_posted_by(); ?>
				<span class="author-email">
					<a href="mailto:<?php echo esc_attr(get_the_author_meta('user_email')); ?>">
						<?php echo get_the_author_meta('user_email'); ?>
					</a>
				</span>
			</div>

			<?php echo get_the_author_meta('description'); ?>
		</div>
	</div>

	<?php
}

if ( ! function_exists( 'quna_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function quna_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ' ', 'quna' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'quna' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ' ', 'list item separator', 'quna' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'quna' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'quna' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'quna' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'quna_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function quna_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail('full'); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
			the_post_thumbnail( 'quna-post-thumbnail-medium' );
			?>
		</a>

		<?php
		endif; // End is_singular().
	}
endif;


/**
 * Footer widgets area class
 */
function quna_footer_widgets_area_class() {

	$prefix = 'quna_';
	$has_bg = ( '' != get_theme_mod($prefix.'footer_bg_image') ) ? 'has-bg' : '';

	if ( is_active_sidebar( 'sidebar-2' ) || is_active_sidebar( 'sidebar-3' ) || is_active_sidebar( 'sidebar-4' ) || is_active_sidebar( 'sidebar-5' ) || is_active_sidebar( 'sidebar-6' ) ) {
		echo 'class="has-footer-widget '.$has_bg.'"';
	}

}

/**
 * Back to top anchor
 */
function quna_to_top_anchor() {
	?>
	<a href="#page" id="to-top-anchor"><?php echo apply_filters('quna_gotop_icon', '<i class="fa fa-arrow-up"></i>'); ?></a>
	<?php
}


/**
 * Sticky post label
 */
function quna_post_sticky_label() {
	?>
	<span class="post-sticky-label"><?php echo apply_filters('quna_sticky_icon', '<i class="fa fa-bookmark"></i>'); ?></span>
	<?php
}
